% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vca.R
\name{Solve}
\alias{Solve}
\title{Solve System of Linear Equations using Inverse of Cholesky-Root}
\usage{
Solve(X, quiet = FALSE)
}
\arguments{
\item{X}{(matrix, Matrix) object to be inverted}

\item{quiet}{(logical) TRUE = will suppress any warning, which will be issued otherwise}
}
\value{
(matrix, Matrix) corresponding to the inverse of X
}
\description{
Function solves a system of linear equations, respectively, inverts a matrix
by means of the inverse Cholesky-root.
}
\details{
This function is intended to reduce the computational time in function
\code{\link{solveMME}} which computes the inverse of the square variance-
covariance Matrix of observations. It is considerably faster than function
\code{\link{solve}} (see example).
Whenever an error occurs, which is the case for non positive definite matrices
'X', function \code{\link{MPinv}} is called automatically yielding a generalized
inverse (Moore-Penrose inverse) of 'X'.
}
\examples{
\dontrun{
# following complex (nonsense) model takes pretty long to fit
system.time(res.sw <- anovaVCA(y~(sample+lot+device)/day/run, VCAdata1))
# solve mixed model equations (not automatically done to be more efficient)
system.time(res.sw <- solveMME(res.sw))
# extract covariance matrix of observations V
V1 <- getMat(res.sw, "V")
V2 <- as.matrix(V1)
system.time(V2i <- solve(V2))
system.time(V1i <- VCA:::Solve(V1))
V1i <- as.matrix(V1i)
dimnames(V1i) <- NULL
dimnames(V2i) <- NULL
all.equal(V1i, V2i)
} 
}
\author{
Andre Schuetzenmeister \email{andre.schuetzenmeister@roche.com}
}
